@@ -16,10 +16,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from urllib import parse as urlparse
+
 from oslo_config import cfg
 from oslo_log import log
-import six.moves.urllib.parse as urlparse
 
+from watcher._i18n import _
 from watcher.common import clients
 from watcher.common import exception
 from watcher.decision_engine.datasources import base
@@ -187,6 +189,12 @@ class GrafanaHelper(base.DataSourceBase):
 
         return result
 
+    def statistic_series(self, resource=None, resource_type=None,
+                         meter_name=None, start_time=None, end_time=None,
+                         granularity=300):
+        raise NotImplementedError(
+            _('Grafana helper does not support statistic series method'))
+
     def get_host_cpu_usage(self, resource, period=300,
                            aggregate="mean", granularity=None):
         return self.statistic_aggregation(
